# coding: utf-8

# flake8: noqa
"""
    Regula Face Recognition Web API

    Regula Face Recognition Web API  # noqa: E501

    The version of the OpenAPI document: 0.1.0
    Generated by: https://openapi-generator.tech
"""


from __future__ import absolute_import

# import models into model package
from regula.facerecognition.webclient.gen.models.compare_image import CompareImage
from regula.facerecognition.webclient.gen.models.compare_image_result import CompareImageResult
from regula.facerecognition.webclient.gen.models.compare_request import CompareRequest
from regula.facerecognition.webclient.gen.models.compare_response import CompareResponse
from regula.facerecognition.webclient.gen.models.compare_response_all_of import CompareResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_request import DetectRequest
from regula.facerecognition.webclient.gen.models.detect_response import DetectResponse
from regula.facerecognition.webclient.gen.models.detect_response_all_of import DetectResponseAllOf
from regula.facerecognition.webclient.gen.models.detect_result import DetectResult
from regula.facerecognition.webclient.gen.models.detection import Detection
from regula.facerecognition.webclient.gen.models.face_recognition_result import FaceRecognitionResult
from regula.facerecognition.webclient.gen.models.face_recognition_result_code import FaceRecognitionResultCode
from regula.facerecognition.webclient.gen.models.image_source import ImageSource
from regula.facerecognition.webclient.gen.models.operation_log import OperationLog
