from regula.facerecognition.webclient.ext.models.compare_request import CompareRequest
from regula.facerecognition.webclient.ext.models.compare_image import CompareImage
from regula.facerecognition.webclient.ext.models.detect_request import DetectRequest
